@@ -139,6 +139,7 @@ public:
     callback_t m_preoption_help  = [](const ArgParse&, std::ostream&) {};
     callback_t m_postoption_help = [](const ArgParse&, std::ostream&) {};
     ParamValueList m_params;
+    std::string m_version;
 
     Impl(ArgParse& parent, int argc, const char** argv)
         : m_argparse(parent)
@@ -438,6 +439,22 @@ ArgParse::Impl::parse_args(int xargc, const char** xargv)
     m_argc = xargc;
     m_argv = xargv;
 
+    // Add version option if requested
+    if (m_version.size() && !find_option("--version")) {
+        m_option.emplace(m_option.begin(),
+                         new ArgOption(m_argparse, "--version"));
+        m_option[0]->m_help   = "Print version and exit";
+        m_option[0]->m_action = [&](Arg& arg, cspan<const char*> myarg) {
+            Strutil::print("{}\n", m_version);
+            if (m_exit_on_error)
+                exit(EXIT_SUCCESS);
+            else {
+                m_argparse.abort();
+            }
+        };
+        m_option[0]->initialize();
+    }
+
     // Add help option if requested
     if (m_add_help && !find_option("--help")) {
         m_option.emplace(m_option.begin(), new ArgOption(m_argparse, "--help"));
@@ -914,6 +931,15 @@ ArgParse::add_help(bool add_help)
 
 
 
+ArgParse&
+ArgParse::add_version(string_view version)
+{
+    m_impl->m_version = version;
+    return *this;
+}
+
+
+
 ArgParse&
 ArgParse::exit_on_error(bool exit_on_error)
 {
@@ -1012,8 +1038,8 @@ ArgParse::print_help() const
                     std::cout << "\n    " << std::string(maxlen + 2, ' ');
                 std::string h = opt->help();
                 if (m_impl->m_print_defaults && cparams().contains(opt->dest()))
-                    h += Strutil::sprintf(" (default: %s)",
-                                          cparams()[opt->dest()].get());
+                    h += Strutil::fmt::format(" (default: {})",
+                                              cparams()[opt->dest()].get());
                 std::cout << Strutil::wordwrap(h, columns - 2,
                                                (int)maxlen + 2 + 4 + 2);
                 std::cout << '\n';
