@@ -763,8 +763,8 @@ Strutil::repeat(string_view str, int n)
     size_t sl  = str.size();
     size_t len = sl * std::max(0, n);
     std::unique_ptr<char[]> heap_buf;
-    char local_buf[256];
-    char* buf = local_buf;
+    char local_buf[256] = "";
+    char* buf           = local_buf;
     if (len > sizeof(local_buf)) {
         heap_buf.reset(new char[len]);
         buf = heap_buf.get();
@@ -862,6 +862,7 @@ Strutil::utf16_to_utf8(const std::wstring& str) noexcept
 char*
 Strutil::safe_strcpy(char* dst, string_view src, size_t size) noexcept
 {
+    OIIO_DASSERT(dst);
     if (src.size()) {
         size_t end = std::min(size - 1, src.size());
         for (size_t i = 0; i < end; ++i)
@@ -877,6 +878,30 @@ Strutil::safe_strcpy(char* dst, string_view src, size_t size) noexcept
 
 
 
+char*
+Strutil::safe_strcat(char* dst, string_view src, size_t size) noexcept
+{
+    OIIO_DASSERT(dst);
+    if (src.size()) {
+        size_t dstsize = strnlen(dst, size);
+        size_t end     = std::min(size - dstsize - 1, src.size());
+        for (size_t i = 0; i < end; ++i)
+            dst[dstsize + i] = src[i];
+        dst[dstsize + end] = 0;
+    }
+    return dst;
+}
+
+
+
+size_t
+Strutil::safe_strlen(const char* str, size_t size) noexcept
+{
+    return str ? strnlen(str, size) : 0;
+}
+
+
+
 void
 Strutil::skip_whitespace(string_view& str) noexcept
 {
