@@ -115,6 +115,10 @@ private:
         size_t slen = std::min(s.length(), len - 1);
         return fwrite(s.c_str(), slen) && pad(len - slen);
     }
+
+    template<class T>
+    static void deassociateAlpha(T* data, int size, int channels,
+                                 int alpha_channel, float gamma);
 };
 
 
@@ -543,9 +547,9 @@ TGAOutput::flush_rawp(unsigned char*& src, int size, int start)
 
 
 template<class T>
-static void
-deassociateAlpha(T* data, int size, int channels, int alpha_channel,
-                 float gamma)
+void
+TGAOutput::deassociateAlpha(T* data, int size, int channels, int alpha_channel,
+                            float gamma)
 {
     unsigned int max = std::numeric_limits<T>::max();
     if (gamma == 1) {
